Build a compact HTML report
Arguments
- obj
A
scdown_obj.- signatures
Character vector of built-in signature names or a named list of signatures.
- panels
Character vector of built-in marker panel names or a named list of marker panels.
- signature_sets
Optional named list of custom signatures.
- marker_panels
Optional named list of custom marker panels.
- outdir
Output directory.